@@ -5,13 +5,15 @@ import re
 from typing import Any, List, Optional
 from orionis.console.args.argument import CLIArgument
 from orionis.console.base.command import BaseCommand
-from orionis.console.contracts.command import IBaseCommand
+from orionis.console.contracts.base_command import IBaseCommand
+from orionis.console.contracts.cli_request import ICLIRequest
+from orionis.console.contracts.command import ICommand
 from orionis.console.contracts.reactor import IReactor
-from orionis.console.enums.command import Command
-from orionis.console.exceptions import CLIOrionisValueError
-from orionis.console.exceptions.cli_runtime_error import CLIOrionisRuntimeError
-from orionis.console.output.contracts.console import IConsole
-from orionis.console.output.contracts.executor import IExecutor
+from orionis.console.entities.command import Command
+from orionis.console.exceptions import CLIOrionisValueError, CLIOrionisRuntimeError
+from orionis.console.contracts.executor import IExecutor
+from orionis.console.exceptions import CLIOrionisTypeError
+from orionis.console.request.cli_request import CLIRequest
 from orionis.foundation.contracts.application import IApplication
 from orionis.services.introspection.modules.reflection import ReflectionModule
 from orionis.services.log.contracts.log_service import ILogger
@@ -58,31 +60,199 @@ class Reactor(IReactor):
         # Initialize the application instance, using provided app or creating new Orionis instance
         self.__app = app
 
-        # Set the project root directory to current working directory for module path resolution
-        self.__root = self.__app.path('root')
-
         # Initialize the internal command registry as an empty dictionary
         self.__commands: dict[str, Command] = {}
 
-        # Automatically discover and load command classes from the console commands directory
-        cli_commands_path = (Path(self.__app.path('console')) / 'commands').resolve()
-        self.__loadCommands(cli_commands_path, self.__root)
-
-        # Load core command classes provided by the Orionis framework
-        self.__loadCoreCommands()
-
         # Initialize the executor for command output management
         self.__executer: IExecutor = self.__app.make('x-orionis.console.output.executor')
 
-        # Initialize the console for command output
-        self.__console: IConsole = self.__app.make('x-orionis.console.output.console')
-
         # Initialize the logger service for logging command execution details
         self.__logger: ILogger = self.__app.make('x-orionis.services.log.log_service')
 
         # Initialize the performance counter for measuring command execution time
         self.__performance_counter: IPerformanceCounter = self.__app.make('x-orionis.support.performance.counter')
 
+        # List to hold fluent command definitions
+        self.__fluent_commands: List[ICommand] = []
+
+        # Flag to indicate whether commands have been loaded
+        self.__load_commands: bool = False
+
+    def __loadCommands(self) -> None:
+        """
+        Loads all available commands for the console application.
+
+        This method orchestrates the loading of both custom user-defined commands and
+        core framework commands into the reactor's internal command registry. It implements
+        a lazy loading pattern using an internal flag to ensure commands are loaded only
+        once during the reactor instance's lifetime, preventing duplicate registrations
+        and improving performance on subsequent calls.
+
+        The loading process follows a specific order: custom commands are loaded first,
+        followed by core framework commands. This ensures that custom commands can
+        potentially override core commands if they share the same signature, giving
+        users the flexibility to customize framework behavior.
+
+        Returns
+        -------
+        None
+            This method does not return any value. All discovered commands are
+            registered internally in the reactor's command registry and become
+            available for execution through the `call` and `callAsync` methods.
+
+        Notes
+        -----
+        - Commands are loaded only once per reactor instance to prevent duplicates
+        - Custom commands are loaded before core commands to allow potential overrides
+        - The internal `__load_commands` flag tracks whether commands have been loaded
+        - Both loading methods handle their own error handling and validation
+        """
+
+        # Check if commands have already been loaded to prevent duplicate loading
+        if not self.__load_commands:
+
+            # Load custom user-defined commands from the project's commands directory
+            self.__loadCustomCommands()
+
+            # Load core framework commands that are bundled with Orionis
+            self.__loadCoreCommands()
+
+            # Load commands defined using the fluent interface
+            self.__loadFluentCommands()
+
+            # Set the flag to indicate that commands have been successfully loaded
+            self.__load_commands = True
+
+    def __loadFluentCommands(self) -> None:
+        """
+        Loads and registers commands defined using the fluent interface.
+
+        This method iterates through all commands that have been defined using the
+        fluent interface pattern and registers them in the reactor's internal command
+        registry. Each fluent command is validated for structure and metadata before
+        being added to ensure proper integration and discoverability.
+
+        Returns
+        -------
+        None
+            This method does not return any value. All fluent commands are
+            registered internally in the reactor's command registry for later lookup
+            and execution.
+        """
+
+        # Import library for dynamic module importing
+        import importlib
+
+        # Get the routes directory path from the application instance
+        routes_path = self.__app.path('routes')
+
+        # Check if routes directory exists
+        if not os.path.exists(routes_path):
+            return
+
+        # Get the project root directory for module path resolution
+        root_path = self.__app.getBasePath()
+
+        # List all .py files in the routes directory and subdirectories
+        for current_directory, _, files in os.walk(routes_path):
+
+            # Iterate through each file in the current directory
+            for file in files:
+
+                # Only process Python files
+                if file.endswith('.py'):
+
+                    # Construct the full file path
+                    file_path = os.path.join(current_directory, file)
+
+                    # Read file content to check for Reactor.command usage
+                    try:
+
+                        # Open and read the file content
+                        with open(file_path, 'r', encoding='utf-8') as f:
+                            content = f.read()
+
+                        # Check if the file contains a Reactor.command definition
+                        if 'from orionis.support.facades.reactor import Reactor' in content:
+
+                            # Sanitize the module path for import
+                            pre_module = current_directory.replace(root_path, '')\
+                                                          .replace(os.sep, '.')\
+                                                          .lstrip('.')
+
+                            # Remove virtual environment paths
+                            pre_module = re.sub(r'[^.]*\.(?:Lib|lib)\.(?:python[^.]*\.)?site-packages\.?', '', pre_module)
+                            pre_module = re.sub(r'\.?v?env\.?', '', pre_module)
+                            pre_module = re.sub(r'\.+', '.', pre_module).strip('.')
+
+                            # Skip if module name is empty after cleaning
+                            if not pre_module:
+                                continue
+
+                            # Create the reflection module path
+                            module_name = f"{pre_module}.{file[:-3]}"
+
+                            try:
+
+                                # Import the module natively using importlib
+                                importlib.import_module(module_name)
+
+                            except Exception as e:
+
+                                # Raise a runtime error if module import fails
+                                raise CLIOrionisRuntimeError(
+                                    f"Failed to import module '{module_name}' from file '{file_path}': {e}"
+                                ) from e
+
+                    except Exception as e:
+
+                        # Raise a runtime error if file reading fails
+                        raise CLIOrionisRuntimeError(
+                            f"Failed to read file '{file_path}' for fluent command loading: {e}"
+                        ) from e
+
+        # Import Command entity here to avoid circular imports
+        from orionis.console.entities.command import Command as CommandEntity
+
+        # Iterate through all fluent command definitions
+        for f_command in self.__fluent_commands:
+
+            # If the fluent command has a get method, retrieve its signature and command entity
+            if hasattr(f_command, 'get') and callable(getattr(f_command, 'get')):
+
+                # Get the signature and command entity from the fluent command
+                values = f_command.get()
+                signature: str = values[0]
+                command_entity: CommandEntity = values[1]
+
+                # Build the arguments dictionary from the CLIArgument instances
+                required_args: List[CLIArgument] = command_entity.args
+
+                # Create an ArgumentParser instance to handle the command arguments
+                arg_parser = argparse.ArgumentParser(
+                    usage=f"python -B reactor {signature} [options]",
+                    description=f"Command [{signature}] : {command_entity.description}",
+                    formatter_class=argparse.RawTextHelpFormatter,
+                    add_help=True,
+                    allow_abbrev=False,
+                    exit_on_error=True,
+                    prog=signature
+                )
+
+                # Iterate through each CLIArgument and add it to the ArgumentParser
+                for arg in required_args:
+                    arg.addToParser(arg_parser)
+
+                # Register the command in the internal registry with all its metadata
+                self.__commands[signature] = Command(
+                    obj=command_entity.obj,
+                    method=command_entity.method,
+                    timestamps=command_entity.timestamps,
+                    signature=signature,
+                    description=command_entity.description,
+                    args=arg_parser
+                )
+
     def __loadCoreCommands(self) -> None:
         """
         Loads and registers core command classes provided by the Orionis framework.
@@ -114,6 +284,7 @@ class Reactor(IReactor):
         from orionis.console.commands.cache import CacheClearCommand
         from orionis.console.commands.scheduler_work import ScheduleWorkCommand
         from orionis.console.commands.scheduler_list import ScheduleListCommand
+        from orionis.console.commands.make_listener import MakeListenerCommand
 
         # List of core command classes to load (extend this list as more core commands are added)
         core_commands = [
@@ -124,28 +295,36 @@ class Reactor(IReactor):
             WorkFlowGithubCommand,
             CacheClearCommand,
             ScheduleWorkCommand,
-            ScheduleListCommand
+            ScheduleListCommand,
+            MakeListenerCommand
         ]
 
         # Iterate through the core command classes and register them
         for obj in core_commands:
 
+            # Get the signature attribute from the command class
+            signature = getattr(obj, 'signature', None)
+
+            # Skip if signature is not defined
+            if signature is None:
+                continue
+
             # Validate and extract required command attributes
             timestamp = self.__ensureTimestamps(obj)
-            signature = getattr(obj, 'signature', None)
             description = self.__ensureDescription(obj)
             args = self.__ensureArguments(obj)
 
             # Register the command in the internal registry with all its metadata
             self.__commands[signature] = Command(
                 obj=obj,
+                method='handle',
                 timestamps=timestamp,
                 signature=signature,
                 description=description,
                 args=args
             )
 
-    def __loadCommands(self, commands_path: str, root_path: str) -> None:
+    def __loadCustomCommands(self) -> None:
         """
         Loads command classes from Python files in the specified commands directory.
 
@@ -154,13 +333,6 @@ class Reactor(IReactor):
         sanitization to handle virtual environment paths and validates command structure
         before registration.
 
-        Parameters
-        ----------
-        commands_path : str
-            The absolute path to the directory containing command modules to load.
-        root_path : str
-            The root path of the project, used for module path normalization.
-
         Returns
         -------
         None
@@ -175,8 +347,14 @@ class Reactor(IReactor):
         - Each discovered command class undergoes structure validation via __ensureStructure
         """
 
+        # Ensure the provided commands_path is a valid directory
+        commands_path = (Path(self.__app.path('console')) / 'commands').resolve()
+        root_path = self.__app.getBasePath()
+
         # Iterate through the command path and load command modules
         for current_directory, _, files in os.walk(commands_path):
+
+            # Iterate through each file in the current directory
             for file in files:
 
                 # Only process Python files
@@ -220,6 +398,7 @@ class Reactor(IReactor):
                             # Add the command to the internal registry
                             self.__commands[signature] = Command(
                                 obj=obj,
+                                method='handle',
                                 timestamps=timestamp,
                                 signature=signature,
                                 description=description,
@@ -256,7 +435,7 @@ class Reactor(IReactor):
 
         # Ensure the timestamps attribute is a boolean type
         if not isinstance(obj.timestamps, bool):
-            raise TypeError(f"Command class {obj.__name__} 'timestamps' must be a boolean.")
+            raise CLIOrionisTypeError(f"Command class {obj.__name__} 'timestamps' must be a boolean.")
 
         # Return timestamps value
         return obj.timestamps
@@ -282,24 +461,24 @@ class Reactor(IReactor):
 
         Raises
         ------
-        ValueError
+        CLIOrionisValueError
             If the command class lacks a 'signature' attribute, if the signature
             is an empty string, or if the signature doesn't match the required pattern.
-        TypeError
+        CLIOrionisTypeError
             If the 'signature' attribute is not a string.
         """
 
         # Check if the command class has a signature attribute
         if not hasattr(obj, 'signature'):
-            raise ValueError(f"Command class {obj.__name__} must have a 'signature' attribute.")
+            raise CLIOrionisValueError(f"Command class {obj.__name__} must have a 'signature' attribute.")
 
         # Ensure the signature attribute is a string type
         if not isinstance(obj.signature, str):
-            raise TypeError(f"Command class {obj.__name__} 'signature' must be a string.")
+            raise CLIOrionisTypeError(f"Command class {obj.__name__} 'signature' must be a string.")
 
         # Validate that the signature is not empty after stripping whitespace
         if obj.signature.strip() == '':
-            raise ValueError(f"Command class {obj.__name__} 'signature' cannot be an empty string.")
+            raise CLIOrionisValueError(f"Command class {obj.__name__} 'signature' cannot be an empty string.")
 
         # Define the regex pattern for valid signature format
         # Pattern allows: alphanumeric chars, underscores, colons
@@ -308,7 +487,7 @@ class Reactor(IReactor):
 
         # Validate the signature against the required pattern
         if not re.match(pattern, obj.signature):
-            raise ValueError(f"Command class {obj.__name__} 'signature' must contain only alphanumeric characters, underscores (_) and colons (:), cannot start or end with underscore or colon, and cannot start with a number.")
+            raise CLIOrionisValueError(f"Command class {obj.__name__} 'signature' must contain only alphanumeric characters, underscores (_) and colons (:), cannot start or end with underscore or colon, and cannot start with a number.")
 
         # Return signature
         return obj.signature.strip()
@@ -334,24 +513,24 @@ class Reactor(IReactor):
 
         Raises
         ------
-        ValueError
+        CLIOrionisValueError
             If the command class lacks a 'description' attribute or if the description
             is an empty string after stripping whitespace.
-        TypeError
+        CLIOrionisTypeError
             If the 'description' attribute is not a string type.
         """
 
         # Check if the command class has a description attribute
         if not hasattr(obj, 'description'):
-            raise ValueError(f"Command class {obj.__name__} must have a 'description' attribute.")
+            raise CLIOrionisValueError(f"Command class {obj.__name__} must have a 'description' attribute.")
 
         # Ensure the description attribute is a string type
         if not isinstance(obj.description, str):
-            raise TypeError(f"Command class {obj.__name__} 'description' must be a string.")
+            raise CLIOrionisTypeError(f"Command class {obj.__name__} 'description' must be a string.")
 
         # Validate that the description is not empty after stripping whitespace
         if obj.description.strip() == '':
-            raise ValueError(f"Command class {obj.__name__} 'description' cannot be an empty string.")
+            raise CLIOrionisValueError(f"Command class {obj.__name__} 'description' cannot be an empty string.")
 
         # Return description
         return obj.description.strip()
@@ -376,7 +555,7 @@ class Reactor(IReactor):
 
         Raises
         ------
-        TypeError
+        CLIOrionisTypeError
             If the 'arguments' attribute is not a list or contains non-CLIArgument instances.
         """
 
@@ -386,7 +565,7 @@ class Reactor(IReactor):
 
         # Ensure the arguments attribute is a list type
         if not isinstance(obj.arguments, list):
-            raise TypeError(f"Command class {obj.__name__} 'arguments' must be a list.")
+            raise CLIOrionisTypeError(f"Command class {obj.__name__} 'arguments' must be a list.")
 
         # If arguments is empty, return None
         if len(obj.arguments) == 0:
@@ -395,7 +574,7 @@ class Reactor(IReactor):
         # Validate that all items in the arguments list are CLIArgument instances
         for index, value in enumerate(obj.arguments):
             if not isinstance(value, CLIArgument):
-                raise TypeError(f"Command class {obj.__name__} 'arguments' must contain only CLIArgument instances, found '{type(value).__name__}' at index {index}.")
+                raise CLIOrionisTypeError(f"Command class {obj.__name__} 'arguments' must contain only CLIArgument instances, found '{type(value).__name__}' at index {index}.")
 
         # Build the arguments dictionary from the CLIArgument instances
         required_args: List[CLIArgument] = obj.arguments
@@ -475,6 +654,68 @@ class Reactor(IReactor):
             # Return an empty dictionary if no arguments were parsed
             return {}
 
+    def command(
+        self,
+        signature: str,
+        handler: List[Any]
+    ) -> ICommand:
+        """
+        Define a new command using a fluent interface.
+
+        This method allows defining a new command with a specified signature and handler
+        function using a fluent interface pattern. The command can be further configured
+        by chaining additional method calls to set properties such as timestamps,
+        description, and arguments.
+
+        Parameters
+        ----------
+        signature : str
+            The unique signature identifier for the command. Must follow naming conventions
+            (alphanumeric characters, underscores, colons, cannot start/end with underscore
+            or colon, cannot start with a number).
+        handler : List[Any]
+            A list containing the class and optionally the method name. The first element
+            should be a class, and the second element (if provided) should be a string
+            representing the method name.
+
+        Returns
+        -------
+        ICommand
+            Returns an instance of ICommand that allows further configuration of the command
+            through method chaining.
+
+        Raises
+        ------
+        CLIOrionisTypeError
+            If the signature is not a string or if the handler is not a valid list.
+        ValueError
+            If the signature does not meet the required naming conventions.
+        """
+
+        # Import the FluentCommand class here to avoid circular imports
+        from orionis.console.fluent.command import Command as FluentCommand
+
+        # Validate the handler parameter
+        if len(handler) < 1 or not isinstance(handler, list):
+            raise CLIOrionisValueError("Handler must be a list with at least one element (the callable).")
+
+        # Ensure the first element is a class
+        if not hasattr(handler[0], '__call__') or not hasattr(handler[0], '__name__'):
+            raise CLIOrionisTypeError("The first element of handler must be a class.")
+
+        # Create a new FluentCommand instance with the provided signature and handler
+        f_command = FluentCommand(
+            signature=signature,
+            concrete=handler[0],
+            method=handler[1] if len(handler) > 1 else 'handle'
+        )
+
+        # Append the new command to the internal list of fluent commands
+        self.__fluent_commands.append(f_command)
+
+        # Return the newly created command for further configuration
+        return self.__fluent_commands[-1]
+
     def info(self) -> List[dict]:
         """
         Retrieves a list of all registered commands with their metadata.
@@ -491,6 +732,9 @@ class Reactor(IReactor):
             contains the command's signature, description, and timestamps status.
         """
 
+        # Ensure commands are loaded before retrieving information
+        self.__loadCommands()
+
         # Prepare a list to hold command information
         commands_info = []
 
@@ -556,51 +800,64 @@ class Reactor(IReactor):
         - All exceptions are logged and displayed in the console.
         """
 
-        # Retrieve the command from the registry by its signature
-        command: Command = self.__commands.get(signature)
-        if command is None:
-            raise CLIOrionisValueError(f"Command '{signature}' not found.")
+        # Scope Request instances to this command execution context
+        with self.__app.createContext():
 
-        # Start execution timer for performance measurement
-        self.__performance_counter.start()
+            # Ensure commands are loaded before attempting to execute
+            self.__loadCommands()
 
-        # Log the command execution start with RUNNING state if timestamps are enabled
-        if command.timestamps:
-            self.__executer.running(program=signature)
+            # Retrieve the command from the registry by its signature
+            command: Command = self.__commands.get(signature)
+            if command is None:
+                raise CLIOrionisValueError(f"Command '{signature}' not found.")
 
-        try:
-            # Instantiate the command class using the application container
-            command_instance: IBaseCommand = self.__app.make(command.obj)
+            # Start execution timer for performance measurement
+            self.__performance_counter.start()
 
-            # Inject parsed arguments into the command instance
-            command_instance._args = self.__parseArgs(command, args)
-
-            # Execute the command's handle method and capture its output
-            output = self.__app.call(command_instance, 'handle')
-
-            # Calculate elapsed time and log completion with DONE state if command.timestamps are enabled
-            elapsed_time = round(self.__performance_counter.stop(), 2)
+            # Log the command execution start with RUNNING state if timestamps are enabled
             if command.timestamps:
-                self.__executer.done(program=signature, time=f"{elapsed_time}s")
+                self.__executer.running(program=signature)
 
-            # Log successful execution in the logger service
-            self.__logger.info(f"Command '{signature}' executed successfully in ({elapsed_time}) seconds.")
+            try:
+                # Instantiate the command class using the application container
+                command_instance: IBaseCommand = self.__app.make(command.obj)
 
-            # Return the output produced by the command, if any
-            return output
+                # Inject parsed arguments into the command instance
+                _args = self.__parseArgs(command, args)
+                command_instance._args = _args.copy()
 
-        except Exception as e:
+                # Inject a scoped CLIRequest instance into the application container for the command's context
+                self.__app.scopedInstance(ICLIRequest, CLIRequest(
+                    command=signature,
+                    args=_args.copy()
+                ))
 
-            # Log the error in the logger service
-            self.__logger.error(f"Command '{signature}' execution failed: {e}")
+                # Execute the command's handle method and capture its output
+                output = self.__app.call(command_instance, command.method)
 
-            # Calculate elapsed time and log failure with ERROR state if command.timestamps are enabled
-            elapsed_time = round(self.__performance_counter.stop(), 2)
-            if command.timestamps:
-                self.__executer.fail(program=signature, time=f"{elapsed_time}s")
+                # Calculate elapsed time and log completion with DONE state if command.timestamps are enabled
+                elapsed_time = round(self.__performance_counter.stop(), 2)
+                if command.timestamps:
+                    self.__executer.done(program=signature, time=f"{elapsed_time}s")
 
-            # Propagate the exception after logging
-            raise
+                # Log successful execution in the logger service
+                self.__logger.info(f"Command '{signature}' executed successfully in ({elapsed_time}) seconds.")
+
+                # Return the output produced by the command, if any
+                return output
+
+            except Exception as e:
+
+                # Log the error in the logger service
+                self.__logger.error(f"Command '{signature}' execution failed: {e}")
+
+                # Calculate elapsed time and log failure with ERROR state if command.timestamps are enabled
+                elapsed_time = round(self.__performance_counter.stop(), 2)
+                if command.timestamps:
+                    self.__executer.fail(program=signature, time=f"{elapsed_time}s")
+
+                # Propagate the exception after logging
+                raise
 
     async def callAsync(
         self,
@@ -644,48 +901,61 @@ class Reactor(IReactor):
         - All exceptions are logged and displayed in the console.
         """
 
-        # Retrieve the command from the registry by its signature
-        command: Command = self.__commands.get(signature)
-        if command is None:
-            raise CLIOrionisValueError(f"Command '{signature}' not found.")
+        # Scope Request instances to this command execution context
+        with self.__app.createContext():
 
-        # Start execution timer for performance measurement
-        self.__performance_counter.start()
+            # Ensure commands are loaded before attempting to execute
+            self.__loadCommands()
 
-        # Log the command execution start with RUNNING state if timestamps are enabled
-        if command.timestamps:
-            self.__executer.running(program=signature)
+            # Retrieve the command from the registry by its signature
+            command: Command = self.__commands.get(signature)
+            if command is None:
+                raise CLIOrionisValueError(f"Command '{signature}' not found.")
 
-        try:
-            # Instantiate the command class using the application container
-            command_instance: IBaseCommand = self.__app.make(command.obj)
+            # Start execution timer for performance measurement
+            self.__performance_counter.start()
 
-            # Inject parsed arguments into the command instance
-            command_instance._args = self.__parseArgs(command, args)
-
-            # Execute the command's handle method asynchronously and capture its output
-            output = await self.__app.callAsync(command_instance, 'handle')
-
-            # Calculate elapsed time and log completion with DONE state if command.timestamps are enabled
-            elapsed_time = round(self.__performance_counter.stop(), 2)
+            # Log the command execution start with RUNNING state if timestamps are enabled
             if command.timestamps:
-                self.__executer.done(program=signature, time=f"{elapsed_time}s")
+                self.__executer.running(program=signature)
 
-            # Log successful execution in the logger service
-            self.__logger.info(f"Command '{signature}' executed successfully in ({elapsed_time}) seconds.")
+            try:
+                # Instantiate the command class using the application container
+                command_instance: IBaseCommand = self.__app.make(command.obj)
 
-            # Return the output produced by the command, if any
-            return output
+                # Inject parsed arguments into the command instance
+                _args = self.__parseArgs(command, args)
+                command_instance._args = _args.copy()
 
-        except Exception as e:
+                # Inject a scoped CLIRequest instance into the application container for the command's context
+                self.__app.scopedInstance(ICLIRequest, CLIRequest(
+                    command=signature,
+                    args=_args.copy()
+                ))
 
-            # Log the error in the logger service
-            self.__logger.error(f"Command '{signature}' execution failed: {e}")
+                # Execute the command's handle method asynchronously and capture its output
+                output = await self.__app.callAsync(command_instance, 'handle')
 
-            # Calculate elapsed time and log failure with ERROR state if command.timestamps are enabled
-            elapsed_time = round(self.__performance_counter.stop(), 2)
-            if command.timestamps:
-                self.__executer.fail(program=signature, time=f"{elapsed_time}s")
+                # Calculate elapsed time and log completion with DONE state if command.timestamps are enabled
+                elapsed_time = round(self.__performance_counter.stop(), 2)
+                if command.timestamps:
+                    self.__executer.done(program=signature, time=f"{elapsed_time}s")
 
-            # Propagate the exception after logging
-            raise
\ No newline at end of file
+                # Log successful execution in the logger service
+                self.__logger.info(f"Command '{signature}' executed successfully in ({elapsed_time}) seconds.")
+
+                # Return the output produced by the command, if any
+                return output
+
+            except Exception as e:
+
+                # Log the error in the logger service
+                self.__logger.error(f"Command '{signature}' execution failed: {e}")
+
+                # Calculate elapsed time and log failure with ERROR state if command.timestamps are enabled
+                elapsed_time = round(self.__performance_counter.stop(), 2)
+                if command.timestamps:
+                    self.__executer.fail(program=signature, time=f"{elapsed_time}s")
+
+                # Propagate the exception after logging
+                raise
\ No newline at end of file
