@@ -1,6 +1,5 @@
 from abc import ABC, abstractmethod
 from pathlib import Path
-from orionis.foundation.contracts.application import IApplication
 
 class IDirectory(ABC):
 
@@ -28,6 +27,30 @@ class IDirectory(ABC):
         """
         pass
 
+    @abstractmethod
+    def consoleCommands(self) -> Path:
+        """
+        Get the console commands directory path.
+
+        Returns
+        -------
+        Path
+            The path to the console commands directory.
+        """
+        pass
+
+    @abstractmethod
+    def consoleListeners(self) -> Path:
+        """
+        Get the console listeners directory path.
+
+        Returns
+        -------
+        Path
+            The path to the console listeners directory.
+        """
+        pass
+
     @abstractmethod
     def controllers(self) -> Path:
         """
